Function for fitting bagged logicDT models.
# S3 method for default
logicDT.bagging(X, y, Z = NULL, bagging.iter = 500, ...)# S3 method for formula
logicDT.bagging(formula, data, ...)
An object of class logic.bagged. This is a list
containing
modelsA list of fitted logicDT models
bagsA list of observation indices which were used to train each model
...Supplied parameters of the functional call
to logicDT.bagging.
Matrix or data frame of binary predictors coded as 0 or 1.
Response vector. 0-1 coding for binary responses. Otherwise, a regression task is assumed.
Optional matrix or data frame of quantitative/continuous covariables. Multiple covariables allowed for splitting the trees. If leaf regression models (such as four parameter logistic models) shall be fitted, only the first given covariable is used.
Number of bagging iterations
Arguments passed to logicDT
An object of type formula describing the
model to be fitted.
A data frame containing the data for the corresponding
formula object. Must also contain quantitative covariables
if they should be included as well.
Details on single logicDT models can be found in logicDT.